# Reporting a security issues

If you believe you have found a security issue in the CKEditor 4 software, please contact us immediately.

When reporting a potential security problem, please bear this in mind:

*   Make sure to provide as many details as possible about the vulnerability.
*   Please do not disclose publicly any security issues until we fix them and publish security releases.

Contact the security team at security@cksource.com. As soon as we receive the security report, we will work promptly to confirm the issue and then to provide a security fix.
